@@ -365,7 +365,7 @@ void AccountDialog::makeLocalAccountPage()
   groupLayout->setSpacing( 6 );
   groupLayout->setMargin( 11 );
 
-  mLocal.lockProcmail = new TQRadioButton( i18n("Procmail loc&tdefile:"), group);
+  mLocal.lockProcmail = new TQRadioButton( i18n("Procmail loc&kfile:"), group);
   groupLayout->addWidget(mLocal.lockProcmail, 0, 0);
 
   mLocal.procmailLockFileName = new TQComboBox( true, group );
