@@ -11,7 +11,7 @@
 #include <tdeio/job.h>
 #include "kmmsgbase.h" // for KMMsgStatus
 #include <mimelib/string.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 #include <kservice.h>
 #include <tdetempfile.h>
 
