@@ -26,7 +26,7 @@ class KMReaderMainWin : public KMail::SecondaryWindow
   
 
 public:
-  KMReaderMainWin( bool htmlOverride, bool htmlLoadExtOverride, char *name = 0 );
+  KMReaderMainWin( bool htmlOverride, bool htmlLoadExtDefault, char *name = 0 );
   KMReaderMainWin( char *name = 0 );
   KMReaderMainWin(KMMessagePart* aMsgPart,
     bool aHTML, const TQString& aFileName, const TQString& pname,
