@@ -453,6 +453,11 @@ TQString KNote::noteId() const
     return m_journal->uid();
 }
 
+TQDateTime KNote::getLastModified() const
+{
+    return m_journal->lastModified();
+}
+
 TQString KNote::name() const
 {
     return m_label->text();
