@@ -342,6 +342,15 @@ TQMap<TQString,TQString> KNotesApp::notes() const
     return notes;
 }
 
+TQDateTime KNotesApp::getLastModified( const TQString& id ) const
+{
+    KNote* note = m_noteList[id];
+    TQDateTime d;
+    if ( note )
+        d = note->getLastModified();
+    return d;
+}
+
 TQString KNotesApp::name( const TQString& id ) const
 {
     KNote* note = m_noteList[id];
