@@ -19,7 +19,7 @@
 
 #include <tqcstring.h>
 
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class KDE_EXPORT KTQCStringSplitter {
   
