@@ -29,7 +29,7 @@
 
 #include "kpgp.h"
 
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class TQString;
 class TQRegExp;
@@ -62,7 +62,7 @@ class KDE_EXPORT PassphraseDialog : public KDialogBase
                       bool modal=true, const TQString &keyID=TQString());
     virtual ~PassphraseDialog();
 
-    const char * passphrase();
+    TQString passphrase();
 
   private:
     KPasswordEdit *lineedit;
