@@ -582,7 +582,7 @@ void ExchangeDownload::slotPropFindResult( TDEIO::Job *job )
   if ( mCalendar ) {
     KCal::Event *oldEvent = mCalendar->event( event->uid() );
     if ( oldEvent ) {
-      kdWarning() << "Already got his event, replace it..." << endl;
+      kdWarning() << "Already got the event, replace it..." << endl;
       mCalendar->deleteEvent( oldEvent );
     }
     kdDebug() << "ADD EVENT" << endl;
