@@ -376,14 +376,14 @@ void ResourceCalDav::loadFinished() {
     if (loader->error()) {
         if (loader->errorNumber() == -401) {
             if (NULL != mPrefs) {
-                TQCString newpass;
+                TQString newpass;
                 if (KPasswordDialog::getPassword (newpass, TQString("<b>") + i18n("Remote authorization required") + TQString("</b><p>") + i18n("Please input the password for") + TQString(" ") + mPrefs->getusername(), NULL) != 1) {
                     log("load error: " + loader->errorString() );
                     loadError(TQString("[%1] ").arg(abs(loader->errorNumber())) + loader->errorString());
                 }
                 else {
                     // Set new password and try again
-                    mPrefs->setPassword(TQString(newpass));
+                    mPrefs->setPassword(newpass);
                     startLoading(mPrefs->getFullUrl(), mPrefs->getFullTasksUrl(), mPrefs->getFullJournalsUrl());
                 }
             }
@@ -424,14 +424,14 @@ void ResourceCalDav::loadFinished() {
     if (loader->tasksError()) {
         if (loader->tasksErrorNumber() == -401) {
             if (NULL != mPrefs) {
-//                 TQCString newpass;
+//                 TQString newpass;
 //                 if (KPasswordDialog::getPassword (newpass, TQString("<b>") + i18n("Remote authorization required") + TQString("</b><p>") + i18n("Please input the password for") + TQString(" ") + mPrefs->getusername(), NULL) != 1) {
 //                     log("load error: " + loader->tasksErrorString() );
 //                     loadError(TQString("[%1] ").arg(abs(loader->tasksErrorNumber())) + loader->tasksErrorString());
 //                 }
 //                 else {
 //                     // Set new password and try again
-//                     mPrefs->setPassword(TQString(newpass));
+//                     mPrefs->setPassword(newpass);
 //                     startLoading(mPrefs->getFullUrl(), mPrefs->getFullTasksUrl(), mPrefs->getFullJournalsUrl());
 //                 }
             }
@@ -472,14 +472,14 @@ void ResourceCalDav::loadFinished() {
     if (loader->journalsError()) {
         if (loader->journalsErrorNumber() == -401) {
             if (NULL != mPrefs) {
-//                 TQCString newpass;
+//                 TQString newpass;
 //                 if (KPasswordDialog::getPassword (newpass, TQString("<b>") + i18n("Remote authorization required") + TQString("</b><p>") + i18n("Please input the password for") + TQString(" ") + mPrefs->getusername(), NULL) != 1) {
 //                     log("load error: " + loader->journalsErrorString() );
 //                     loadError(TQString("[%1] ").arg(abs(loader->journalsErrorNumber())) + loader->journalsErrorString());
 //                 }
 //                 else {
 //                     // Set new password and try again
-//                     mPrefs->setPassword(TQString(newpass));
+//                     mPrefs->setPassword(newpass);
 //                     startLoading(mPrefs->getFullUrl(), mPrefs->getFullTasksUrl(), mPrefs->getFullJournalsUrl());
 //                 }
             }
@@ -969,14 +969,14 @@ void ResourceCalDav::writingFinished() {
     if (mWriter->error() && (abs(mWriter->errorNumber()) != 207)) {
         if (mWriter->errorNumber() == -401) {
             if (NULL != mPrefs) {
-                TQCString newpass;
+                TQString newpass;
                 if (KPasswordDialog::getPassword (newpass, TQString("<b>") + i18n("Remote authorization required") + TQString("</b><p>") + i18n("Please input the password for") + TQString(" ") + mPrefs->getusername(), NULL) != 1) {
                     log("write error: " + mWriter->errorString());
                     saveError(TQString("[%1] ").arg(abs(mWriter->errorNumber())) + mWriter->errorString());
                 }
                 else {
                     // Set new password and try again
-                    mPrefs->setPassword(TQString(newpass));
+                    mPrefs->setPassword(newpass);
                     startWriting(mPrefs->getFullUrl(), mPrefs->getFullTasksUrl(), mPrefs->getFullJournalsUrl());
                 }
             }
