@@ -206,11 +206,11 @@ class KDE_EXPORT ResourceXMLRPC : public ResourceCached
     void init();
     void initEGroupware();
 
-    void writeEvent( Event*, TQMap<TQString, TQVariant>& );
-    void readEvent( const TQMap<TQString, TQVariant>&, Event*, TQString& );
+    void writeEvent( Event*, TQStringVariantMap& );
+    void readEvent( const TQStringVariantMap&, Event*, TQString& );
 
-    void writeTodo( Todo*, TQMap<TQString, TQVariant>& );
-    void readTodo( const TQMap<TQString, TQVariant>&, Todo*, TQString& );
+    void writeTodo( Todo*, TQStringVariantMap& );
+    void readTodo( const TQStringVariantMap&, Todo*, TQString& );
 
     void checkLoadingFinished();
 
