@@ -84,8 +84,8 @@ class KDE_EXPORT ResourceXMLRPC : public ResourceNotes
     void init();
     void initEGroupware();
 
-    void writeNote( KCal::Journal*, TQMap<TQString, TQVariant>& );
-    void readNote( const TQMap<TQString, TQVariant>&, KCal::Journal*, TQString& );
+    void writeNote( KCal::Journal*, TQStringVariantMap& );
+    void readNote( const TQStringVariantMap&, KCal::Journal*, TQString& );
 
     KCal::CalendarLocal mCalendar;
     KXMLRPC::Server *mServer;
